@@ -64,33 +64,6 @@ def _num_tokens_from_messages(messages, model="gpt-4"):
     return num_tokens
 
 
-def _chunk_transcript(transcript: str, chunk_size: int) -> List[str]:
-    return [
-        transcript[i : i + chunk_size] for i in range(0, len(transcript), chunk_size)
-    ]
-
-
-def _sumarise_chunk(chunk: str, model: str, temperature: float) -> str:
-    system_prompt = (
-        "You are a meeting assistant. You have excellent language abilities."
-        "You will take a transcript and shorten the transcript without modifying the meaning of the conversation."
-        "Shorten the provided transcript by preserving all of the speakers' turns, key information, and specific guidance offered without redundancy."
-        "The provided transcript takes the form `Speaker: Utterance`."
-        "You will return a shortened transcript in the same format, but shorten each utterance where possible."
-        "Make sure you retain all key information including action items. dates. numbers, etc."
-        "Try to shorten the overall transcript to half the length."
-    )
-    messages = [
-        {"role": "system", "content": system_prompt},
-        {"role": "user", "content": chunk},
-    ]
-
-    response = openai.ChatCompletion.create(
-        model=model, temperature=temperature, messages=messages
-    )
-    return response["choices"][0]["message"]["content"]
-
-
 def _content_to_message(content: str):
     messages = [
         {"role": "system", "content": _system_prompt_summariser()},
@@ -102,36 +75,6 @@ def _content_to_message(content: str):
     return messages
 
 
-def _shorten_transcript(transcript: str, chunk_size: int = 8192) -> str:
-    chunks = _chunk_transcript(transcript, chunk_size)
-
-    summarized_chunks = []
-
-    for chunk in chunks:
-        messages = _content_to_message(chunk)
-
-        if _num_tokens_from_messages(messages, model="gpt-4") > 8192:
-            raise ChunkTooLongError(
-                "The chunk is too long, consider reducing chunk_size."
-            )
-
-        summarized_chunk = _sumarise_chunk(chunk, model="gpt-4", temperature=0.1)
-        summarized_chunks.append(summarized_chunk)
-
-    shortened_transcript = " ".join(summarized_chunks).strip()
-
-    if (
-        _num_tokens_from_messages(
-            _content_to_message(shortened_transcript), model="gpt-4"
-        )
-        > 8192
-    ):
-        print("Shortened transcript is still too long, reducing chunk size...")
-        return _shorten_transcript(transcript, chunk_size=chunk_size)
-
-    return shortened_transcript
-
-
 def _system_prompt_summariser():
     """Generate the system prompt for the GPT model.
 
